.. :changelog:

History
-------

0.5.1 (2015-05-18)
~~~~~~~~~~~~~~~~~~
* Add support for line comments.
* Fix packages in setup.py. (thanks @michaelaye)


0.5.0 (2015-04-18)
~~~~~~~~~~~~~~~~~~
* Add support for python 2.6/3.3/3.4
* Simplified command api.
* Labels package now shares the json module api.
* Label parser now fully conforms to the PVL spec.
* Add label encoder.


0.4.0 (2015-03-21)
~~~~~~~~~~~~~~~~~~

* First release on PyPI.
